==> smartgwt-6.1p.zip: com/smartgwt/client/widgets/form/fields/events/PickerIconClickHandler.java <==
/*
 * Smart GWT (GWT for SmartClient)
 * Copyright 2008 and beyond, Isomorphic Software, Inc.
 *
 * Smart GWT is free software; you can redistribute it and/or modify it
 * under the terms of the GNU Lesser General Public License version 3
 * as published by the Free Software Foundation.  Smart GWT is also
 * available under typical commercial license terms - see
 * http://smartclient.com/license
 *
 * This software is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
 * Lesser General Public License for more details.
 */
/* sgwtgen */
 
package com.smartgwt.client.widgets.form.fields.events;

import com.google.gwt.event.shared.EventHandler;

public interface PickerIconClickHandler extends EventHandler {
    /**
     * Notification method called when the {@link com.smartgwt.client.widgets.form.fields.FormItem#getShowPickerIcon picker
     * icon} is clicked. This method will fire after the {@link
     * com.smartgwt.client.widgets.form.fields.FormItemIcon#addFormItemClickHandler FormItemIcon.formItemClick()} handler for
     * the {@link com.smartgwt.client.widgets.form.fields.FormItem#getPickerIconProperties pickerIcon}. If the event is not
     * cancelled,  the standard {@link com.smartgwt.client.widgets.form.fields.FormItem#addIconClickHandler
     * FormItem.iconClick()} will also fire.
     *
     * @param event the event
     */
    void onPickerIconClick(com.smartgwt.client.widgets.form.fields.events.PickerIconClickEvent event);
}

==> smartgwt-13.0p.zip: com/smartgwt/client/widgets/form/fields/events/PickerIconClickHandler.java <==
/*
 * Smart GWT (GWT for SmartClient)
 * Copyright 2008 and beyond, Isomorphic Software, Inc.
 *
 * Smart GWT is free software; you can redistribute it and/or modify it
 * under the terms of the GNU Lesser General Public License version 3
 * as published by the Free Software Foundation.  Smart GWT is also
 * available under typical commercial license terms - see
 * http://smartclient.com/license
 *
 * This software is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
 * Lesser General Public License for more details.
 */
/* sgwtgen */
 
package com.smartgwt.client.widgets.form.fields.events;

import com.google.gwt.event.shared.EventHandler;

public interface PickerIconClickHandler extends EventHandler {
    /**
     * Notification method called when the {@link com.smartgwt.client.widgets.form.fields.FormItem#getShowPickerIcon picker
     * icon} is clicked. This method will fire after the {@link
     * com.smartgwt.client.widgets.form.fields.FormItemIcon#addFormItemClickHandler FormItemIcon.formItemClick()} handler for
     * the {@link com.smartgwt.client.widgets.form.fields.FormItem#getPickerIconProperties pickerIcon}. If the event is not
     * cancelled,  the standard {@link com.smartgwt.client.widgets.form.fields.FormItem#addIconClickHandler
     * FormItem.iconClick()} will also fire. <P> The default implementation will call {@link
     * com.smartgwt.client.widgets.form.fields.FormItem#showPicker showPicker()}.
     *
     * @param event the event
     */
    void onPickerIconClick(com.smartgwt.client.widgets.form.fields.events.PickerIconClickEvent event);
}
